@@ -1,17 +1,16 @@
 #' tidysq: tidy analysis of biological sequences
 #'
-#' @description The \code{tidysq} package is a toolbox for the analysis of 
+#' @description The \code{tidysq} package is a toolbox for the analysis of
 #' biological sequences in a tidy way.
 #' @author Michal Burdukiewicz, Dominik Rafacz, Laura Bąkała, Leon Eyrich Jessen
-#' @docType package
 #' @importFrom stats rnorm setNames
 #' @importFrom tibble as_tibble tibble
 #' @import checkmate
 #' @import vctrs
 #' @name tidysq-package
 #' @aliases tidysq
-NULL
+"_PACKAGE"
 
 #' @useDynLib tidysq, .registration=TRUE
 #' @importFrom Rcpp sourceCpp
-NULL
\ No newline at end of file
+NULL
